<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ext="java:lu.bourse.api.deposant.action.xsl.XslManager"
	xmlns:ns="http://www.bourse.lu/rap/S211"
	xmlns:fnbourse="http://www.bcl.lu/2006/bcl-xpath-functions"
	exclude-result-prefixes="ext fnbourse"
	version="2.0">

	<xsl:output method="xml" indent="yes" />
	
	<xsl:param name="spaceParam" />
	<xsl:param name="mappingParam" />

	<!--  -->
	<!-- Début Partie sur les Tests de Contrôles liées aux fichiers Déposés -->
	<!--  -->


	<xsl:template name="obtenirDateFormatee">
		<xsl:param name="dateEntree" />
		<xsl:param name="formatEntree" />
		<xsl:param name="formatSortie" />
		<xsl:variable name="timeVide" select="'00:00:00'" />

		<xsl:choose>
			<xsl:when test="$formatEntree='ddmmyyyy'">
				<xsl:choose>
					<xsl:when test="$formatSortie='date'">
						<xsl:value-of
							select="concat(substring($dateEntree, 5, 4), '-', substring($dateEntree, 3, 2), '-', substring($dateEntree, 1, 2))" />
					</xsl:when>
					<xsl:when test="$formatSortie='dateTime'">
						<xsl:value-of
							select="concat(substring($dateEntree, 5, 4), '-', substring($dateEntree, 3, 2), '-', substring($dateEntree, 1, 2), 'T', $timeVide)" />
					</xsl:when>
				</xsl:choose>
			</xsl:when>

			<xsl:when test="$formatEntree='yyyymmdd_hhmmss'">
				<xsl:choose>
					<xsl:when test="$formatSortie='date'">
						<xsl:value-of
							select="concat(substring($dateEntree, 1, 4), '-', substring($dateEntree, 5, 2), '-', substring($dateEntree, 7, 2))" />
					</xsl:when>
					<xsl:when test="$formatSortie='dateTime'">
						<xsl:value-of
							select="concat(substring($dateEntree, 1, 4), '-', substring($dateEntree, 5, 2), '-', substring($dateEntree, 7, 2), 'T', substring($dateEntree, 10, 2), ':', substring($dateEntree, 12, 2), ':', substring($dateEntree, 14, 2))" />
					</xsl:when>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:template>


	<xsl:template name="boucleTest" match="/file">

		<xsl:param name="iteration" select="1" />


		<xsl:if test="count(row) > $iteration ">
			<xsl:call-template name="boucleTest">
				<xsl:with-param name="iteration"
					select="$iteration + 1" />
			</xsl:call-template>
		</xsl:if>

		<!--  -->
		<!-- Fin Partie sur les Tests de Contrôles liés aux fichiers Déposés -->
		<!--  -->

		<!--  -->
		<!--  On n'effectue la transformation em Message Pivot seulement si l'ensemble des Tests ont été réalisés avec succès -->
		<!--  -->
		<xsl:if test="$iteration = count(row)">
			<ns:MsgInS211>
				<ns:Vers SchemaVers="1.0">
					<xsl:variable name="numVersXSD"
						select="ext:recupNumVersXSDFile($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$numVersXSD" />
				</ns:Vers>
				<xsl:call-template name="ELT-TECH" />
				<ns:SeqInS211>
					<ns:Conc1>
						<xsl:call-template name="SEQUENCE-IN-S211" />
					</ns:Conc1>
				</ns:SeqInS211>
			</ns:MsgInS211>
		</xsl:if>
	</xsl:template>

	<xsl:template name="replace-string">
	  <xsl:param name="str" />
		<xsl:param name="strToReplace" />
		<xsl:param name="newStr" />
		<xsl:choose>
  		<xsl:when test="contains($str,$strToReplace)">
        <xsl:value-of select="concat(substring-before($str,$strToReplace),$newStr)"/>
        <xsl:call-template name="replace-string"> 
          <xsl:with-param name="str" select="substring-after($str,$strToReplace)" /> 
          <xsl:with-param name="strToReplace" select="$strToReplace" /> 
          <xsl:with-param name="newStr" select="$newStr" /> 
        </xsl:call-template> 
      </xsl:when> 
      <xsl:otherwise>
        <xsl:value-of select="$str"/>
      </xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="ELT-TECH">
		<ns:other>
			<ns:EltTech>
				<ns:ListeDev>
					<xsl:value-of select="ext:getListeDevises()" />
				</ns:ListeDev>
				<ns:CdLang>
					<xsl:value-of select="ext:getLang()" />
				</ns:CdLang>
				<ns:UrlCombo>
					<xsl:value-of select="ext:recupDonnee('WS_URL_COMBO', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlCombo>
				<ns:UrlDownload>
					<xsl:value-of select="ext:recupDonnee('WS_URL_DOWNLOAD', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlDownload>
				<ns:UrlCmun>
					<xsl:value-of select="ext:recupDonnee('WS_URL_COMMUN', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlCmun>
				<ns:CdIdentAcCssf>
					<xsl:value-of select="ext:obtenirCdAcCssf($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:CdIdentAcCssf>
				<ns:CdIdentAcBcl>
					<xsl:value-of select="ext:obtenirCdAc($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:CdIdentAcBcl>
				<ns:DtCre>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtCre>
				<ns:DtEnvoi>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtEnvoi>
				<ns:DtValidat>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtValidat>
				<ns:NumMess>
					<xsl:variable name="numMess"
						select="ext:recupNumeroMessage($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$numMess" />
				</ns:NumMess>
				<ns:MotPasAc>
					<xsl:variable name="pwdAc"
						select="ext:obtenirPwdAc($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$pwdAc" />
				</ns:MotPasAc>
				<ns:CdAuthent>
					<xsl:variable name="cdAuth"
						select="ext:obtenirCodeAuth($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$cdAuth" />
				</ns:CdAuthent>
				<ns:CdOpe>
					<xsl:value-of
						select="row[@id='filtre2501']/col[@id=3]" />
				</ns:CdOpe>
				<ns:Sess>
					<xsl:value-of select="''" />
				</ns:Sess>
				<ns:IdTypeDoc>
					<xsl:variable name="typeDoc"
						select="ext:recupDonnee('TYPE_DOC', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$typeDoc" />
				</ns:IdTypeDoc>
			</ns:EltTech>
		</ns:other>
	</xsl:template>

	<xsl:template name="SEQUENCE-IN-S211">
		<xsl:call-template name="SEGMENT-CONTEXT" />
		<xsl:call-template name="SEGMENT-ACTIF" />
		<xsl:call-template name="SEGMENT-PASSIF" />
	</xsl:template>

	<xsl:template name="SEGMENT-CONTEXT">
		<ns:Context>
			<xsl:call-template name="CONTEXT-STRUCTJUROPC" />
			<xsl:call-template name="CONTEXT-TECH" />
			<xsl:call-template name="CONTEXT-TECHCONTACT" />
			<xsl:call-template name="CONTEXT-CODIFINSTRFONDS" />
			<xsl:call-template name="CONTEXT-INSTRFONDS" />
			<xsl:call-template name="CONTEXT-CDINTERNEFONDS" />
			<xsl:call-template name="CONTEXT-CODIFINSTRCOMPART" />
			<xsl:call-template name="CONTEXT-INSTRCOMPART" />
			<xsl:call-template name="CONTEXT-CDINTERNECOMPART" />
			<xsl:call-template name="CONTEXT-DEV" />
			<xsl:call-template name="CONTEXT-CONTEXTRAPS2111" />
		</ns:Context>
	</xsl:template>

	<xsl:template name="CONTEXT-STRUCTJUROPC">
		<ns:StructJurOpc>
			<ns:CdStructJurOpc>
				<xsl:variable name="idStructJurOpc"
					select="ext:recupDonnee('IDSTRUCTJUROPC', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$idStructJurOpc" />
			</ns:CdStructJurOpc>
		</ns:StructJurOpc>
	</xsl:template>

	<xsl:template name="CONTEXT-TECH">
		<ns:Tech>
			<ns:Adr>
				<xsl:variable name="adresse1"
					select="ext:recupDonnee('ADDRESSE1', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$adresse1" />
				<xsl:variable name="adresse2"
					select="ext:recupDonnee('ADDRESSE2', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$adresse2" />
			</ns:Adr>
			<ns:CdPostal>
				<xsl:variable name="cdpostal"
					select="ext:recupDonnee('CDPOSTAL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$cdpostal" />
			</ns:CdPostal>
			<ns:Ville>
				<xsl:variable name="ville"
					select="ext:recupDonnee('VILLE', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$ville" />
			</ns:Ville>
			<ns:Pays>
				<xsl:variable name="pays"
					select="ext:recupDonnee('IDPAYS', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$pays" />
			</ns:Pays>
		</ns:Tech>
	</xsl:template>


	<xsl:template name="CONTEXT-TECHCONTACT">
		<ns:TechContact>
			<ns:Titre>
				<xsl:value-of select="''" />
			</ns:Titre>
			<ns:Nom>
				<xsl:variable name="nomUtil"
					select="ext:recupDonnee('NOMUTIL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$nomUtil" />
			</ns:Nom>
			<ns:Prenom>
				<xsl:variable name="prenomUtil"
					select="ext:recupDonnee('PRENOMUTIL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$prenomUtil" />
			</ns:Prenom>
			<ns:Tel>
				<xsl:variable name="tel"
					select="ext:recupDonnee('TEL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$tel" />
			</ns:Tel>
		</ns:TechContact>
	</xsl:template>

	<xsl:template name="CONTEXT-CODIFINSTRFONDS">
		<ns:CodifInstrFonds>
			<ns:CodifInstr>
				<xsl:value-of select="row[@id='filtre2501']/col[@id=4]" />
			</ns:CodifInstr>
		</ns:CodifInstrFonds>
	</xsl:template>

	<xsl:template name="CONTEXT-INSTRFONDS">
		<ns:InstrFonds>
			<ns:LibAbrInstr>
				<xsl:variable name="libInstrFonds"
					select="ext:obtenirContextForm(row[@id='filtre2501']/ficOri, row[@id='filtre2501']/ligneOri,'FONDS', row[@id='filtre2501']/col[@id=4], row[@id='filtre2501']/col[@id=5], row[@id='filtre2501']/col[@id=6], row[@id='filtre2501']/col[@id=7], $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:call-template name="replace-string">
				  <xsl:with-param name="str"
						select="$libInstrFonds" />
					<xsl:with-param name="strToReplace"
						select="'&#128;'" /><!-- On remplace le caractere euro par un encoding euro correct pour l'afficher correctement dans les pdf'-->
					<xsl:with-param name="newStr"
						select="'&#8364;'" />
				</xsl:call-template>
			</ns:LibAbrInstr>
		</ns:InstrFonds>
	</xsl:template>

	<xsl:template name="CONTEXT-CDINTERNEFONDS">
		<ns:CdInterneFonds>
			<xsl:value-of select="row[@id='filtre2501']/col[@id=6]" />
		</ns:CdInterneFonds>
	</xsl:template>

	<xsl:template name="CONTEXT-CODIFINSTRCOMPART">
		<ns:CodifInstrCompart>
			<ns:CodifInstr>
				<xsl:value-of select="row[@id='filtre2501']/col[@id=5]" />
			</ns:CodifInstr>
		</ns:CodifInstrCompart>
	</xsl:template>

	<xsl:template name="CONTEXT-INSTRCOMPART">
		<ns:InstrCompart>
			<ns:LibAbrInstr>
				<xsl:variable name="libInstrCompart"
					select="ext:obtenirContextForm(row[@id='filtre2501']/ficOri, row[@id='filtre2501']/ligneOri,'COMPART', row[@id='filtre2501']/col[@id=4], row[@id='filtre2501']/col[@id=5], row[@id='filtre2501']/col[@id=6], row[@id='filtre2501']/col[@id=7], $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:call-template name="replace-string">
				  <xsl:with-param name="str"
						select="$libInstrCompart" />
					<xsl:with-param name="strToReplace"
						select="'&#128;'" /><!-- On remplace le caractere euro par un encoding euro correct pour l'afficher correctement dans les pdf'-->
					<xsl:with-param name="newStr"
						select="'&#8364;'" />
				</xsl:call-template>
			</ns:LibAbrInstr>
		</ns:InstrCompart>
	</xsl:template>

	<xsl:template name="CONTEXT-CDINTERNECOMPART">
		<ns:CdInterneCompart>
			<xsl:value-of select="row[@id='filtre2501']/col[@id=7]" />
		</ns:CdInterneCompart>
	</xsl:template>

	<xsl:template name="CONTEXT-DEV">
		<ns:Dev>
			<ns:CdDevIso>
				<xsl:value-of
					select="row[@id='filtre2501']/col[@id=10]" />
			</ns:CdDevIso>
		</ns:Dev>
	</xsl:template>

	<xsl:template name="CONTEXT-CONTEXTRAPS2111">
		<ns:ContextRapS2111>
			<ns:DtDebRap>
				<xsl:variable name="dtDebRap"
					select="row[@id='filtre2501']/col[@id=8]" />
				<xsl:call-template name="obtenirDateFormatee">
					<xsl:with-param name="dateEntree"
						select="ext:obtenirDate($dtDebRap)" />
					<xsl:with-param name="formatEntree"
						select="'ddmmyyyy'" />
					<xsl:with-param name="formatSortie"
						select="'dateTime'" />
				</xsl:call-template>
			</ns:DtDebRap>
			<ns:DtFinRap>
				<xsl:variable name="dtFinRap"
					select="row[@id='filtre2501']/col[@id=9]" />
				<xsl:call-template name="obtenirDateFormatee">
					<xsl:with-param name="dateEntree"
						select="ext:obtenirDate($dtFinRap)" />
					<xsl:with-param name="formatEntree"
						select="'ddmmyyyy'" />
					<xsl:with-param name="formatSortie"
						select="'dateTime'" />
				</xsl:call-template>
			</ns:DtFinRap>
			<ns:TxChgeIml>
				<xsl:value-of select="format-number(row[@id='filtre2501']/col[@id=11] div 100000, '#.#####')" />
			</ns:TxChgeIml>
		</ns:ContextRapS2111>
	</xsl:template>

	<xsl:template name="decoupe-codeLigneEdifact">
		<xsl:param name="ligne" />
		<xsl:value-of
			select="concat(substring($ligne, 2,1), '-',substring($ligne, 3,3), '-', substring($ligne, 6,2), '-', substring($ligne, 8,3), '-',  substring($ligne, 11,5))" />
	</xsl:template>

	<xsl:template name="obtenirLigneUnitaire">
		<xsl:param name="ligne" />
		<xsl:param name="newline" />
		<xsl:if test="'$newline'='$ligne'">
			<xsl:value-of select="$ligne" />
		</xsl:if>
	</xsl:template>

	<xsl:template name="obtenirPays">
		<xsl:param name="ligne" />
		<ns:Pays>
			<xsl:value-of select="substring($ligne, 7, 2)"
				xmlns:spaceParam="java:lu.bourse.services.workflow.Space"
				xmlns:mappingParam="java:lu.bourse.api.deposant.mapping.MappingHelper"/>		
		</ns:Pays>
	</xsl:template>

	<xsl:template name="obtenirDevise">
		<xsl:param name="ligne" />
			<ns:Dev>
				<xsl:value-of select="substring($ligne, 10, 3)" />
			</ns:Dev>
	</xsl:template>

	<xsl:template name="obtenirSectEco">
		<xsl:param name="ligne" />
		<ns:SectEco>
			<xsl:value-of select="substring($ligne, 14, 5)" />		
		</ns:SectEco>
	</xsl:template>

	<xsl:template name="obtenirPeriode">
		<xsl:param name="ligne" />
		<xsl:choose>
			<xsl:when test="@id='filtre2502'">
				<xsl:if test="col[@id=11]='BRA'">
					<ns:Inf3m>
						<xsl:value-of select="col[@id=12]" />
					</ns:Inf3m>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRB'">
					<ns:Inf1>
						<xsl:value-of select="col[@id=12]" />
					</ns:Inf1>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRC'">
					<ns:Inf1>
						<xsl:value-of select="col[@id=12]" />
					</ns:Inf1>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRG'">
					<ns:Inf2>
						<xsl:value-of select="col[@id=12]" />
					</ns:Inf2>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRH'">
					<ns:Inf5>
						<xsl:value-of select="col[@id=12]" />
					</ns:Inf5>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRJ'">
					<ns:Sup2>
						<xsl:value-of select="col[@id=12]" />
					</ns:Sup2>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRK'">
					<ns:Sup5>
						<xsl:value-of select="col[@id=12]" />
					</ns:Sup5>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRX'">
					<ns:Nv>
						<xsl:value-of select="col[@id=12]" />
					</ns:Nv>
				</xsl:if>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="obtenirContenuBalise">
		<xsl:param name="ligne" />
		<xsl:variable name="valueLine"
			select="ext:initValueLine($spaceParam)"
			xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
		<xsl:if test="$valueLine='true'"></xsl:if>

		<xsl:variable name="firstPass">
			<xsl:call-template name="decoupe-codeLigneEdifact">
				<xsl:with-param name="ligne" select="$ligne" />
			</xsl:call-template>
		</xsl:variable>

		<xsl:for-each select="row">
			<xsl:variable name="resultDecoupe">
				<xsl:call-template name="decoupe-codeLigneEdifact">
					<xsl:with-param name="ligne" select="$ligne" />
				</xsl:call-template>
			</xsl:variable>

			<xsl:if test="col[@id=10]=$resultDecoupe">
				<xsl:variable name="valueLine2"
					select="ext:setHasValueLine($spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:if test="$valueLine2='true'"></xsl:if>

				<xsl:call-template name="obtenirLigneUnitaire">
					<xsl:with-param name="newline" select="$firstPass" />
					<xsl:with-param name="ligne"
						select="$resultDecoupe" />
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>

		<xsl:variable name="valueLine3"
			select="ext:obtenirValueLine($spaceParam)"
			xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
		<xsl:if test="$valueLine3='yes'">
			<xsl:variable name="ligneUnitaire" select="$firstPass" />

			<!-- 			<xsl:call-template name="obtenirPays">
				<xsl:with-param name="ligne" select="$ligneUnitaire" />
				</xsl:call-template>
			-->
			<xsl:call-template name="obtenirDevise">
				<xsl:with-param name="ligne" select="$ligneUnitaire" />
			</xsl:call-template>
			<!--				
				<xsl:call-template name="obtenirSectEco">
				<xsl:with-param name="ligne" select="$ligneUnitaire" />
				</xsl:call-template>
			-->
		</xsl:if>

		<xsl:if test="$valueLine3!='yes'">
			<ns:Dev></ns:Dev>
			<!-- 
				<ns:Pays></ns:Pays>
				<ns:SectEco></ns:SectEco>
			-->
		</xsl:if>

		<xsl:if test="substring($ligne, 2,1)='1'">
			<xsl:for-each select="row">
				<xsl:variable name="resultDecoupe">
					<xsl:call-template
						name="decoupe-codeLigneEdifact">
						<xsl:with-param name="ligne" select="$ligne" />
					</xsl:call-template>
				</xsl:variable>

				<xsl:if test="col[@id=10]=$resultDecoupe">
					<xsl:call-template name="obtenirPeriode">
						<xsl:with-param name="ligne"
							select="$resultDecoupe" />
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="substring($ligne, 2,1)='2'">
			<xsl:for-each select="row">
				<xsl:variable name="resultDecoupe">
					<xsl:call-template
						name="decoupe-codeLigneEdifact">
						<xsl:with-param name="ligne" select="$ligne" />
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="col[@id=10]=$resultDecoupe">
					<xsl:call-template name="obtenirPeriode">
						<xsl:with-param name="ligne"
							select="$resultDecoupe" />
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

	<xsl:template name="SEGMENT-ACTIF">
		<ns:Actif>
			<xsl:call-template name="ACTIF-A020LU20000" />
			<xsl:call-template name="ACTIF-A020X320000" />
			<xsl:call-template name="ACTIF-A020X411000" />
			<xsl:call-template name="ACTIF-A020X420000" />
			<xsl:call-template name="ACTIF-A030LU10000" />
			<xsl:call-template name="ACTIF-A030LU20000" />
			<xsl:call-template name="ACTIF-A030X310000" />
			<xsl:call-template name="ACTIF-A030X320000" />
			<xsl:call-template name="ACTIF-A030X411000" />
			<xsl:call-template name="ACTIF-A030X420000" />
		</ns:Actif>
	</xsl:template>

	<xsl:template name="ACTIF-A020LU20000">
		<ns:A020LU20000>
			<ns:Rubr>020</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>LUX</ns:Pays>
				<ns:SectEco>20000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L1020LUDKK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUDKK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUDKK20000>
			<ns:L1020LUSEK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUSEK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUSEK20000>
			<ns:L1020LUGBP20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUGBP20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUGBP20000>
			<ns:L1020LUUSD20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUUSD20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUUSD20000>
			<ns:L1020LUJPY20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUJPY20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUJPY20000>
			<ns:L1020LUCHF20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUCHF20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUCHF20000>
			<ns:L1020LUXX520000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUXX520000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUXX520000>
		</ns:A020LU20000>
	</xsl:template>


	<xsl:template name="ACTIF-A020X320000">
		<ns:A020X320000>
			<ns:Rubr>020</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>X3</ns:Pays>
				<ns:SectEco>20000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L1020X3DKK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3DKK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3DKK20000>
			<ns:L1020X3SEK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3SEK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3SEK20000>
			<ns:L1020X3GBP20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3GBP20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3GBP20000>
			<ns:L1020X3USD20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3USD20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3USD20000>
			<ns:L1020X3JPY20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3JPY20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3JPY20000>
			<ns:L1020X3CHF20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3CHF20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3CHF20000>
			<ns:L1020X3XX520000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3XX520000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3XX520000>
		</ns:A020X320000>
	</xsl:template>

	<xsl:template name="ACTIF-A020X411000">
		<ns:A020X411000>
			<ns:Rubr>020</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>X4</ns:Pays>
				<ns:SectEco>11000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L1020X4DKK11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4DKK11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4DKK11000>
			<ns:L1020X4SEK11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4SEK11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4SEK11000>
			<ns:L1020X4GBP11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4GBP11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4GBP11000>
			<ns:L1020X4USD11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4USD11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4USD11000>
			<ns:L1020X4JPY11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4JPY11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4JPY11000>
			<ns:L1020X4CHF11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4CHF11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4CHF11000>
			<ns:L1020X4XX511000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4XX511000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4XX511000>
		</ns:A020X411000>
	</xsl:template>

	<xsl:template name="ACTIF-A020X420000">
		<ns:A020X420000>
			<ns:Rubr>020</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>X4</ns:Pays>
				<ns:SectEco>20000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L1020X4DKK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4DKK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4DKK20000>
			<ns:L1020X4SEK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4SEK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4SEK20000>
			<ns:L1020X4GBP20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4GBP20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4GBP20000>
			<ns:L1020X4USD20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4USD20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4USD20000>
			<ns:L1020X4JPY20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4JPY20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4JPY20000>
			<ns:L1020X4CHF20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4CHF20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4CHF20000>
			<ns:L1020X4XX520000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4XX520000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4XX520000>
		</ns:A020X420000>
	</xsl:template>

	<xsl:template name="ACTIF-A030LU10000">
		<ns:A030LU10000>
			<ns:Rubr>030</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>LUX</ns:Pays>
				<ns:SectEco>10000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L1030LUDKK10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUDKK10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUDKK10000>
			<ns:L1030LUSEK10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUSEK10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUSEK10000>
			<ns:L1030LUGBP10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUGBP10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUGBP10000>
			<ns:L1030LUUSD10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUUSD10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUUSD10000>
			<ns:L1030LUJPY10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUJPY10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUJPY10000>
			<ns:L1030LUCHF10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUCHF10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUCHF10000>
			<ns:L1030LUXX510000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUXX510000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUXX510000>
		</ns:A030LU10000>
	</xsl:template>

	<xsl:template name="ACTIF-A030LU20000">
		<ns:A030LU20000>
			<ns:Rubr>030</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>LUX</ns:Pays>
				<ns:SectEco>20000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L1030LUDKK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUDKK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUDKK20000>
			<ns:L1030LUSEK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUSEK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUSEK20000>
			<ns:L1030LUGBP20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUGBP20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUGBP20000>
			<ns:L1030LUUSD20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUUSD20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUUSD20000>
			<ns:L1030LUJPY20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUJPY20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUJPY20000>
			<ns:L1030LUCHF20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUCHF20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUCHF20000>
			<ns:L1030LUXX520000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUXX520000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUXX520000>
		</ns:A030LU20000>
	</xsl:template>

	<xsl:template name="ACTIF-A030X310000">
		<ns:A030X310000>
			<ns:Rubr>030</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>X3</ns:Pays>
				<ns:SectEco>10000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L1030X3DKK10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3DKK10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3DKK10000>
			<ns:L1030X3SEK10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3SEK10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3SEK10000>
			<ns:L1030X3GBP10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3GBP10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3GBP10000>
			<ns:L1030X3USD10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3USD10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3USD10000>
			<ns:L1030X3JPY10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3JPY10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3JPY10000>
			<ns:L1030X3CHF10000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3CHF10000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3CHF10000>
			<ns:L1030X3XX510000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3XX510000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3XX510000>
		</ns:A030X310000>
	</xsl:template>

	<xsl:template name="ACTIF-A030X320000">
		<ns:A030X320000>
			<ns:Rubr>030</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>X3</ns:Pays>
				<ns:SectEco>20000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L1030X3DKK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3DKK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3DKK20000>
			<ns:L1030X3SEK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3SEK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3SEK20000>
			<ns:L1030X3GBP20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3GBP20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3GBP20000>
			<ns:L1030X3USD20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3USD20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3USD20000>
			<ns:L1030X3JPY20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3JPY20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3JPY20000>
			<ns:L1030X3CHF20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3CHF20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3CHF20000>
			<ns:L1030X3XX520000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3XX520000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3XX520000>
		</ns:A030X320000>
	</xsl:template>

	<xsl:template name="ACTIF-A030X411000">
		<ns:A030X411000>
			<ns:Rubr>030</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>X4</ns:Pays>
				<ns:SectEco>11000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L1030X4DKK11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4DKK11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4DKK11000>
			<ns:L1030X4SEK11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4SEK11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4SEK11000>
			<ns:L1030X4GBP11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4GBP11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4GBP11000>
			<ns:L1030X4USD11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4USD11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4USD11000>
			<ns:L1030X4JPY11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4JPY11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4JPY11000>
			<ns:L1030X4CHF11000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4CHF11000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4CHF11000>
			<ns:L1030X4XX511000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4XX511000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4XX511000>
		</ns:A030X411000>
	</xsl:template>


	<xsl:template name="ACTIF-A030X420000">
		<ns:A030X420000>
			<ns:Rubr>030</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>X4</ns:Pays>
				<ns:SectEco>20000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L1030X4DKK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4DKK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4DKK20000>
			<ns:L1030X4SEK20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4SEK20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4SEK20000>
			<ns:L1030X4GBP20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4GBP20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4GBP20000>
			<ns:L1030X4USD20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4USD20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4USD20000>
			<ns:L1030X4JPY20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4JPY20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4JPY20000>
			<ns:L1030X4CHF20000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4CHF20000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4CHF20000>
			<ns:L1030X4XX520000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4XX520000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4XX520000>
		</ns:A030X420000>
	</xsl:template>


	<xsl:template name="SEGMENT-PASSIF">
		<ns:Passif>
			<xsl:call-template name="PASSIF-P020LU11000" />
			<xsl:call-template name="PASSIF-P020X320000" />
			<xsl:call-template name="PASSIF-P020X411000" />
			<xsl:call-template name="PASSIF-P110X100000" />
		</ns:Passif>
	</xsl:template>

	<xsl:template name="PASSIF-P020LU11000">
		<ns:P020LU11000>
			<ns:Rubr>020</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>LUX</ns:Pays>
				<ns:SectEco>11000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L2020LUDKK11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020LUDKK11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020LUDKK11000>
			<ns:L2020LUSEK11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020LUSEK11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020LUSEK11000>
			<ns:L2020LUGBP11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020LUGBP11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020LUGBP11000>
			<ns:L2020LUUSD11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020LUUSD11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020LUUSD11000>
			<ns:L2020LUJPY11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020LUJPY11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020LUJPY11000>
			<ns:L2020LUCHF11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020LUCHF11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020LUCHF11000>
			<ns:L2020LUXX511000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020LUXX511000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020LUXX511000>
		</ns:P020LU11000>
	</xsl:template>

	<xsl:template name="PASSIF-P020X320000">
		<ns:P020X311000>
			<ns:Rubr>020</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>X3</ns:Pays>
				<ns:SectEco>11000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L2020X3DKK11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X3DKK11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X3DKK11000>
			<ns:L2020X3SEK11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X3SEK11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X3SEK11000>
			<ns:L2020X3GBP11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X3GBP11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X3GBP11000>
			<ns:L2020X3USD11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X3USD11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X3USD11000>
			<ns:L2020X3JPY11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X3JPY11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X3JPY11000>
			<ns:L2020X3CHF11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X3CHF11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X3CHF11000>
			<ns:L2020X3XX511000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X3XX511000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X3XX511000>
		</ns:P020X311000>
	</xsl:template>

	<xsl:template name="PASSIF-P020X411000">
		<ns:P020X411000>
			<ns:Rubr>020</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>X4</ns:Pays>
				<ns:SectEco>11000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L2020X4DKK11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X4DKK11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X4DKK11000>
			<ns:L2020X4SEK11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X4SEK11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X4SEK11000>
			<ns:L2020X4GBP11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X4GBP11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X4GBP11000>
			<ns:L2020X4USD11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X4USD11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X4USD11000>
			<ns:L2020X4JPY11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X4JPY11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X4JPY11000>
			<ns:L2020X4CHF11000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X4CHF11000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X4CHF11000>
			<ns:L2020X4XX511000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2020X4XX511000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2020X4XX511000>
		</ns:P020X411000>
	</xsl:template>

	<xsl:template name="PASSIF-P110X100000">
		<ns:P110X100000>
			<ns:Rubr>110</ns:Rubr>
			<ns:SectEcoPays>
				<ns:Pays>X1</ns:Pays>
				<ns:SectEco>00000</ns:SectEco>
			</ns:SectEcoPays>
			<ns:L2110X1EUR00000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2110X1EUR00000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2110X1EUR00000>
			<ns:L2110X1DKK00000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2110X1DKK00000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2110X1DKK00000>
			<ns:L2110X1SEK00000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2110X1SEK00000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2110X1SEK00000>
			<ns:L2110X1GBP00000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2110X1GBP00000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2110X1GBP00000>
			<ns:L2110X1USD00000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2110X1USD00000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2110X1USD00000>
			<ns:L2110X1JPY00000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2110X1JPY00000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2110X1JPY00000>
			<ns:L2110X1CHF00000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2110X1CHF00000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2110X1CHF00000>
			<ns:L2110X1XX500000>
				<ns:LigneP>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L2110X1XX500000'" />
					</xsl:call-template>
				</ns:LigneP>
			</ns:L2110X1XX500000>
		</ns:P110X100000>
	</xsl:template>
</xsl:stylesheet>