<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:fnbcl="http://www.bcl.lu/2006/bcl-xpath-functions"
	xmlns:ext="java:lu.bourse.api.deposant.action.xsl.XslManager"
	version="2.0">
	
	<!-- 
		Fonction de remplacement des caracteres speciaux.
	-->
	<xsl:function name="fnbcl:edifact-encode" as="xs:string">
		<!--  La chaine de caracteres a encoder. -->
		<xsl:param name="original" as="xs:string" />
		<!--  caracteres a encoder -> "?" "'" "+" ":" -->
		<xsl:variable name="step1" select="replace($original, '\?', '??')"/>
		<xsl:variable name="step2" select="replace($step1, '''', '?''')"/>
		<xsl:variable name="step3" select="replace($step2, '\+', '?+')"/>
		<xsl:variable name="step4" select="replace($step3, ':', '?:')"/>
		<xsl:variable name="step5" select="ext:encodeEdifact($step4)"/>
		<xsl:value-of select="$step5"/>
	</xsl:function>

	<!-- 
		Fonction de decoupage d'une chaine de caracteres en un nombre 
		maximum de segments delimites par un separateur.
	-->
	<xsl:function name="fnbcl:string-cut" as="xs:string">
		<!--  La chaine de caracteres a decouper. -->
		<xsl:param name="original" as="xs:string" />
		<!--  Le separateur a utiliser. -->
		<xsl:param name="separator" as="xs:string" />
		<!--  La longeur des segments. -->
		<xsl:param name="length" as="xs:integer" />
		<!--  Le nombre maximum de segments. -->
		<xsl:param name="max" as="xs:integer" />
		<!--  1. Verification de la longueur des segments. -->
		<xsl:variable name="length" as="xs:integer">
			<xsl:sequence
				select="
				if ($length eq 0 or $length gt string-length($original))
				then (string-length($original))
				else ($length)
			" />
		</xsl:variable>
		<!--  2. Calcul du nombre de segments dans la chaine de caracteres. -->
		<xsl:variable name="nbTokens">
			<xsl:sequence
				select="
				if (string-length($original) ne 0)
				then (string-length($original) idiv $length) + 
					ceiling(
						(string-length($original) mod $length) div string-length($original)
					)
				else 0
				" />
		</xsl:variable>
		<!--  3. Recuperation des segments. -->
		<xsl:variable name="tokens" as="xs:string*">
			<xsl:sequence
				select="for $i in 1 to $nbTokens
  				return substring($original, (($i - 1) * $length + 1), $length)
  			" />
		</xsl:variable>
		<!--  4. Limitation du nombre de segments. -->
		<xsl:variable name="tokens" as="xs:string*">
			<xsl:sequence
				select="if ($max gt 0) then subsequence($tokens, 1, $max) else $tokens" />
		</xsl:variable>
		<!--  5. Ajout des separateurs entre les segments. -->
		<xsl:sequence select="string-join($tokens, $separator)" />

	</xsl:function>

	<xsl:function name="fnbcl:mapping-maturite" as="xs:string">
		<!--  Code maturite a transformer. -->
		<xsl:param name="code" as="xs:string" />
		<!--  Booleen permettant pour differencier actif et passif. -->
		<xsl:param name="isActif" as="xs:boolean" />
		<xsl:variable name="codeMaturiteActif" as="xs:string*">
			<!-- <= 1 an -->
			<xsl:sequence select="'ns:Inf1'"/>
			<!-- > 1 an et <= 2 ans -->
			<xsl:sequence select="'ns:Inf2'"/>
			<!-- > 2 ans et <= 5 ans -->
			<xsl:sequence select="'ns:Inf5'"/>
			<!-- > 5 ans -->
			<xsl:sequence select="'ns:Sup5'"/>
			<!-- Non ventile -->
			<xsl:sequence select="'ns:Nv'"/>
		</xsl:variable>
		<xsl:variable name="codeMaturiteActifEdifact" as="xs:string*">
			<!-- <= 1 an -->
			<xsl:sequence select="'BRB'"/>
			<!-- > 1 an et <= 2 ans -->
			<xsl:sequence select="'BRG'"/>
			<!-- > 2 ans et <= 5 ans -->
			<xsl:sequence select="'BRH'"/>
			<!-- > 5 ans -->
			<xsl:sequence select="'BRK'"/>
			<!-- Non ventile -->
			<xsl:sequence select="'BRX'"/>
		</xsl:variable>
		<xsl:variable name="codeMaturitePassif" as="xs:string*">
			<!-- <= 3 mois -->
			<xsl:sequence select="'ns:Inf3m'"/>
			<!-- > 3 mois et <= 1 an -->
			<xsl:sequence select="'ns:Inf1'"/>
			<!-- > 1 an et <= 2 ans -->
			<xsl:sequence select="'ns:Inf2'"/>
			<!-- > 2 ans -->
			<xsl:sequence select="'ns:Sup2'"/>
			<!-- Non ventile -->
			<xsl:sequence select="'ns:Nv'"/>
		</xsl:variable>
		<xsl:variable name="codeMaturitePassifEdifact" as="xs:string*">
			<!-- <= 3 mois -->
			<xsl:sequence select="'BRA'"/>
			<!-- > 3 mois et <= 1 an -->
			<xsl:sequence select="'BRC'"/>
			<!-- > 1 an et <= 2 ans -->
			<xsl:sequence select="'BRG'"/>
			<!-- > 2 ans -->
			<xsl:sequence select="'BRJ'"/>
			<!-- Non ventile -->
			<xsl:sequence select="'BRX'"/>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$isActif">
				<xsl:sequence select="
					if (empty(index-of($codeMaturiteActif, $code)))
					then error((), concat('Code maturite actif [', $code,'] inconnu.'))
					else subsequence(
						$codeMaturiteActifEdifact, 
						index-of($codeMaturiteActif, $code),
						1)
			"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:sequence select="
					if (empty(index-of($codeMaturitePassif, $code)))
					then error((), concat('Code maturite passif [', $code,'] inconnu.'))
					else subsequence(
						$codeMaturitePassifEdifact, 
						index-of($codeMaturitePassif, $code),
						1)
			"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>
</xsl:stylesheet>